@@ -1,4 +1,4 @@
-from typing import Callable, Dict, List
+from typing import Callable, Dict, List, Optional
 from django.http import HttpRequest
 
  
@@ -26,4 +26,6 @@ class RudraMetaSettings:
 class RudraBaseSettings:
     success_path: str
     error_path: str
+    user_serializer_path: str
+    fixed_page_number: Optional[int] # for pagination page number
     meta_settings: List[RudraMetaSettings]
\ No newline at end of file
